A data frame with 2,325 observations on 24 variables.
- artist_name
The name of a given artist in a given edition of
Gardner's Art Through the Ages who has created a two-dimensional work
after c. 1750.
- edition_number
The number of the edition of
Gardner's Art Through the Ages.
- title_of_work
The title of the work as listed in
.Gardner's Art Through the Ages
- publication_year
The year of publication.
- page_number_of_image
The page number of the figure of the image
in the text.
- artist_unique_id
A unique number assigned to each artist included
in Gardner's Art Through the Ages that has created a two-dimensional
work after c. 1750.
- artist_nationality
The nationaliity of the artist.
- artist_gender
The gender of the artist.
- artist_race
The race of the artist.
- artist_ethnicity
The ethnicity of the artist.
- height_of_work_in_book
The height in centimeters of the figure of
the work in the book itself.
- width_of_work_in_book
The width in centimeters of the figure of
the work in the book itself.
- height_of_text
The height in centimeters of the text written about
a given work by a given artist in a given edition.
- width_of_text
The width in centimeters of the text written about
a given work by a given artist in a given edition.
- extra_text_height
The height in centimeters of the extra text
written if the text of the work of an artist in not in a rectangular
shape.
- extra_text_width
The width in centimeters of the extra text
written if the text of the work of an artist in not in a rectangular
shape.
- area_of_work_in_book
The area in centimeters squared of a work in
the text.
- area_of_text
The area in centimeters squared written about a work
in the text.
- extra_text_area
The extra area in centimeters squared written about
a work if it is not rectangular in the text.
- total_area_text
The total area in centimeters squared written
about a given work.
- total_space
The area of the work in centimeters squared plus
the area of the text in centimeters squared given to a particular work.
- page_area
The area in centimeters squared of a page in a given
edition of Gardner's Art Through the Ages.
- space_ratio_per_page
The total space in centimeters squared
divided by the area of a page in a given edition.
- book
The name of the book,Gardner's Art Through the Ages,
but gardner for short.