A data frame with 1,634 observations on 25 variables.
- artist_name
The name of a given artist in a given edition of
Janson's Art Through the Ages who has created a two-dimensional work
after c. 1750.
- artist_unique_id
A unique number assigned to each artist included
in Janson's History of Art that has created a two-dimensional
work after c. 1750.
- artist_nationality
The nationaliity of the artist.
- artist_gender
The gender of the artist.
- artist_race
The race of the artist.
- artist_ethnicity
The ethnicity of the artist.
- title_of_work
The title of the work as listed in
.Janson's History of Art
- edition_number
The number of the edition of
Janson's History of Art.
- publication_year
The year of publication.
- part_in_text
The number of the part in the text. In this case,
every work is from part 4, "The Modern World."
- chapter_title
The title of the chapter a given work is in.
- start_date
The year the artist began creating the work.
- end_date
The year the artist finished the work.
- circa
1 if the date of the work was labeled with a circa (around)
and 0 if the date of the work was not labeled with a circa
- medium
The medium of the work.
- height_of_work_in_book
The height in centimeters of the work in
a given edition of Janson's History of Art
- width_of_work_in_book
The width in centimeters of the work in
a given edition of Janson's History of Art
- height_of_text
The height of text in centimeters of the text written
about the work in a given edition of Janson's History of Art
- width_of_text
The width of text in centimeters of the text written
about the work in a given edition of Janson's History of Art
- area_actual_work
The area in centimeters squared of the actual work
itself.
- area_of_work_in_book
The area in centimeter's squared of a given
work in a given edition of Janson's History of Art
- area_of_text
The area in centimeter's squared of the text of given
work in a given edition of Janson's History of Art
- work_to_figure_ratio
The size of the actual work divided by the
size of the work in the book
- work_in_text_in_color
If the figure of the work in
Janson's History of Art was in color, such is denoted by a 1, if the
figure of the work is not in color, such is denoted by a 0.
- location_as_catalogued_in_janson
The location of the work as
catalogued in a given edition of Janson's History of Art.